require 'uri'
require 'httpclient'

module PopupHandlerHelper

  $PopupHandlerURL = "http://localhost:4208"

  def handle_popup(category, options = {}, &block) 
    return if category.nil?
    
    nid = nil
    win_title = options[:win_title]
    case category.to_s
    when "basic_auth"
      username = URI.escape(options[:username] || options[:login])
      password = URI.escape(options[:password])
      if win_title
        escaped_title = URI.escape(win_title)
        nid = notify_popup_handler("/basic_authentication/win_title=#{escaped_title}&user=#{username}&password=#{password}")
      else
        nid = notify_popup_handler("/basic_authentication/user=#{username}&password=#{password}")
      end
      
    when "file_upload"
      file_path = options[:file_path]
      escaped_file_path = URI.escape(file_path)    
      if win_title
        escaped_title = URI.escape(win_title)
        notify_popup_handler("/fileupload/win_title=#{escaped_title}&file=#{escaped_file_path}")
      else    
        win_title = "Choose File to Upload"
        escaped_title = URI.escape(win_title)
        nid = notify_popup_handler("/fileupload/win_title=#{escaped_title}&file=#{escaped_file_path}") 
      end
      
    when "file_download"
      file_path = options[:file_path]
      escaped_file_path = URI.escape(file_path)
      nid = notify_popup_handler("/filedownload/#{escaped_file_path}") 
    when "security"
      nid = notify_popup_handler("/security")
    when "popup", "javascript"
      nid = notify_popup_handler("/popup")   
    end
      
    # invoking 
    yield
      
    notify_popup_handler_cancel(nid) if nid
  end

  def notify_popup_handler(url, in_thread = false)
    the_url = "#{$PopupHandlerURL}#{url}"
    puts "notify url => #{the_url}"
    begin
      res = HTTPClient.new.get(the_url).body
      res = res.content if res.respond_to?("content")
    rescue => e
      puts "[Error] failed to notify the execution monitor: #{e}"
      return nil
    end
  end

  def notify_popup_handler_before_file_upload(file_path, win_title = nil)    
    escaped_file_path = URI.escape(file_path)
    if win_title
      escaped_title = URI.escape(win_title)
      notify_popup_handler("/fileupload/win_title=#{escaped_title}&file=#{escaped_file_path}")
    else
      notify_popup_handler("/fileupload/#{escaped_file_path}")
    end
  end

  def notify_popup_handler_before_security_alerts()
    notify_popup_handler("/security")
  end

  def notify_popup_handler_cancel(id = nil)
    notify_popup_handler("/cancel/#{id}")
  end

end