load File.dirname(__FILE__) + "/../test_helper.rb"

describe "Quiz - Select List" do
  include TestHelper

  before(:all) do
    @driver = Selenium::WebDriver.for(browser_type, browser_options)
  end

  before(:each) do
    driver.navigate.to(site_url + "/select_list.html")
  end

  after(:all) do
    driver.quit unless debugging?
  end

  # Select can either be value or text
  it "Select option by label" do
    Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "car_make")).select_by(:text, "Volvo (Sweden)")
  end

  it "Select option by value" do
    Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "car_make_select")).select_by(:value, "audi")
  end

  it "Select option by index" do
    my_select = Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "car_make_select"))
    my_select.select_by(:index, 2)
    expect(my_select.first_selected_option.text).to eq("Volvo (Sweden)")
  end

  it "Clear single selection" do
    elem = Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "car_make_select"))
    elem.select_by(:text, "Volvo (Sweden)")
    elem.select_by(:value, "")
  end

  it "Clear multiple selects" do
    my_select = Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "test_framework"))
    my_select.select_by(:text, "Selenium")
    my_select.select_by(:text, "RWebSpec")
    my_select.deselect_all
  end

  it "Assert option (label or value) in a select list" do
    my_select = driver.find_element(:id, "car_make_select")
    select_texts = my_select.find_elements(:tag_name => "option").collect { |option| option.text }
    expect(select_texts.include?("Audi (Germany)")).to be_truthy

    select_values = my_select.find_elements(:tag_name => "option").collect { |option| option["value"] }
    expect(select_values.include?("audi")).to be_truthy
  end

  it "Assert selected option" do
    my_select = Selenium::WebDriver::Support::Select.new(driver.find_element(:id, "car_make_select"))
    my_select.select_by(:value, "audi")

    # only works for label not value, the statement below will fail
    # expect(my_select.first_selected_option.value).to eq("audi")
    expect(my_select.first_selected_option.text).to eq("Audi (Germany)")
  end

  it "Assert value of a select list" do
    my_select = Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "car_make"))
    my_select.select_by(:text, "Volvo (Sweden)")
    expect(my_select.first_selected_option["value"]).to eq("volvo")
  end

  it "Assert multiple selected options" do
    my_select = Selenium::WebDriver::Support::Select.new(driver.find_element(:name, "test_framework"))

    my_select.select_by(:text, "Selenium")
    my_select.select_by(:text, "RWebSpec")

    selected = my_select.selected_options
    expect(selected.size).to eq(2)
    expect(selected[0].text).to eq("RWebSpec") # The order is based the option list
    expect(selected[1].text).to eq("Selenium")
  end
end
